@@ -20,6 +20,16 @@
        * @type {!Object.<number, function(?Object)>}
        */
       this._callbacks = {};
+
+      /**
+       * @type {!Array.<!ExtensionDescriptor>}
+       */
+      this._pendingExtensionDescriptors = [];
+
+      /**
+       * @type {?function(!ExtensionDescriptor)}
+       */
+      this._addExtensionCallback = null;
     }
 
     /**
@@ -66,11 +76,14 @@
       // Support for legacy front-ends (<M41).
       if (window['WebInspector'] && window['WebInspector']['addExtensions']) {
         window['WebInspector']['addExtensions'](extensions);
-      } else if (window['InspectorFrontendAPI']) {
+      } else {
         // The addExtensions command is sent as the onload event happens for
-        // DevTools front-end. In case of hosted mode, this
-        // happens before the InspectorFrontendAPI is initialized.
-        this._dispatchOnInspectorFrontendAPI('addExtensions', [extensions]);
+        // DevTools front-end. We should buffer this command until the frontend
+        // is ready for it.
+        if (this._addExtensionCallback)
+          extensions.forEach(this._addExtensionCallback);
+        else
+          this._pendingExtensionDescriptors.pushAll(extensions);
       }
     }
 
@@ -225,6 +238,17 @@
       this._dispatchOnInspectorFrontendAPI('keyEventUnhandled', [event]);
     }
 
+    /**
+     * @param {function(!ExtensionDescriptor)} callback
+     */
+    setAddExtensionCallback(callback) {
+      this._addExtensionCallback = callback;
+      if (this._pendingExtensionDescriptors.length) {
+        this._pendingExtensionDescriptors.forEach(this._addExtensionCallback);
+        this._pendingExtensionDescriptors = [];
+      }
+    }
+
     /**
      * @param {boolean} hard
      */
@@ -539,6 +563,23 @@
       DevToolsAPI.sendMessageToEmbedder('recordEnumeratedHistogram', [actionName, actionCode, bucketSize], null);
     }
 
+    /**
+     * @override
+     * @param {string} histogramName
+     * @param {number} duration
+     */
+    recordPerformanceHistogram(histogramName, duration) {
+      DevToolsAPI.sendMessageToEmbedder('recordPerformanceHistogram', [histogramName, duration], null);
+    }
+
+    /**
+     * @override
+     * @param {string} umaName
+     */
+    recordUserMetricsAction(umaName) {
+      DevToolsAPI.sendMessageToEmbedder('recordUserMetricsAction', [umaName], null);
+    }
+
     /**
      * @override
      */
@@ -760,6 +801,14 @@
       return DevToolsHost.isHostedMode();
     }
 
+    /**
+     * @override
+     * @param {function(!ExtensionDescriptor)} callback
+     */
+    setAddExtensionCallback(callback) {
+      DevToolsAPI.setAddExtensionCallback(callback);
+    }
+
     // Backward-compatible methods below this line --------------------------------------------
 
     /**
@@ -983,6 +1032,7 @@
       'textEditorAutoDetectIndent',
       'textEditorBracketMatching',
       'textEditorIndent',
+      'textEditorTabMovesFocus',
       'timelineCaptureFilmStrip',
       'timelineCaptureLayersAndPictures',
       'timelineCaptureMemory',
