@@ -4,4 +4,4 @@ webInspector.network.getHAR(onHAR);};const extensionsHost='devtools-extensions.o
 try{eval(message.expression);}catch(e){TestRunner.addResult('Exception while running: '+message.expression+'\n'+(e.stack||e));TestRunner.completeTest();}}
 ExtensionsTestRunner.showPanel=function(panelId){if(panelId==='extension')
 panelId=UI.inspectorView._tabbedPane._tabs[UI.inspectorView._tabbedPane._tabs.length-1].id;return UI.inspectorView.showPanel(panelId);};ExtensionsTestRunner.evaluateInExtension=function(code){ExtensionsTestRunner._codeToEvaluateBeforeTests=code;};ExtensionsTestRunner.runExtensionTests=async function(tests){const result=await TestRunner.RuntimeAgent.evaluate('location.href','console',false);if(!result)
-return;ExtensionsTestRunner._pendingTests=(ExtensionsTestRunner._codeToEvaluateBeforeTests||'')+tests.join('\n');const pageURL=result.value;let extensionURL=pageURL.replace(/^(https?:\/\/[^\/]*\/).*$/,'$1')+'devtools/resources/extension-main.html';extensionURL=extensionURL.replace('127.0.0.1',extensionsHost);InspectorFrontendAPI.addExtensions([{startPage:extensionURL,name:'test extension',exposeWebInspectorNamespace:true}]);Extensions.extensionServer.initializeExtensions();};(function disableLogging(){console.warn=()=>undefined;})();;
\ No newline at end of file
+return;ExtensionsTestRunner._pendingTests=(ExtensionsTestRunner._codeToEvaluateBeforeTests||'')+tests.join('\n');const pageURL=result.value;let extensionURL=pageURL.replace(/^(https?:\/\/[^\/]*\/).*$/,'$1')+'devtools/resources/extension-main.html';extensionURL=extensionURL.replace('127.0.0.1',extensionsHost);Extensions.extensionServer._addExtension({startPage:extensionURL,name:'test extension',exposeWebInspectorNamespace:true});};(function disableLogging(){console.warn=()=>undefined;})();;
\ No newline at end of file
